==> Evergreen-ILS-3.15.9.tar.gz: Evergreen-ILS-3.15.9/Open-ILS/web/js/dojo/openils/opac/nls/fr-ca/opac.js <==
{
    ":BARCODE_PROMPT": "Code-barres : ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Annuler",
    ":SUBMIT_BUTTON_LABEL": "Soumettre",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "R\u00e9ponse de r\u00e9initialisation du mot de passe",
    ":PWD_RESET_SUBMIT_SUCCESS": "Votre demande de r\u00e9initialisation du mot de passe a \u00e9t\u00e9 trait\u00e9e. Si une adresse de courriel valide est associ\u00e9e \u00e0 votre compte, vous devriez recevoir sous peu un message contenant les instructions permettant la r\u00e9initialisation de votre mot de passe.",
    ":PWD_RESET_SUBMIT_ERROR": "Le syst\u00e8me n'a pas pu traiter votre demande de r\u00e9initialisation du mot de passe. S'il vous pla\u00eet essayez de nouveau, ou contactez le personnel d'aide pratique.",
    ":PWD_RESET_SUBMIT_STATUS": "Envoi de la demande...",
    ":PWD_RESET_FORGOT_PROMPT": "Mot de passe oubli\u00e9 ?",
    ":PWD_RESET_FORM_TITLE": "Demander un nouveau mot de passe",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "enregistrement MFHD ajout\u00e9 pour ${0}",
    ":CREATED_MFHD_RECORD": "enregistrement MFHD cr\u00e9\u00e9 pour ${0}",
    ":DELETE_MFHD": "Supprimer la notice",
    ":DELETE_MFHD_CONFIRM": "\u00cates-vous s\u00fbr de vouloir supprimer cet enregistrement de s\u00e9rie?",
    ":DELETED_MFHD_RECORD": "Supprimer l'enregistrement MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Modifier la notice",
    ":EDIT_MFHD_MENU": "Modifier fonds",
    ":EDIT_PROPERTIES": "Editer les propri\u00e9t\u00e9s",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Informations suppl\u00e9mentaires sur le volume",
    ":INDEX_HOLDINGS": "Index",
    ":INDEX_HOLDINGS_ADD": "Informations suppl\u00e9mentaires sur l'index",
    ":CURRENT_HOLDINGS": "Volume actuel",
    ":CURRENT_INDEXES": "index courant",
    ":CURRENT_SUPPLEMENTS": "Suppl\u00e9ments actuels",
    ":HOLDINGS_TABLE_CAPTION": "Sommaire de fonds (${0})",
    ":INCOMPLETE_VOLUMES": "Volumes incomplets",
    ":MISSING_VOLUMES": "Volumes manquants",
    ":ONLINE_VOLUMES": "Volumes en ligne",
    ":SAVE_MFHD_LABEL": "Sauvegarder l'enregistrement MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suppl\u00e9ments",
    ":SUPPLEMENT_HOLDINGS_ADD": "Information suppl\u00e9mentaire",
    ":PLACE_HOLD": "R\u00e9serv\u00e9",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "Plus",
    ":MORE_COPIES_FULL_RECORD": "...plus de copies \u00e9num\u00e9r\u00e9s dans l'enregistrement complet",
    ":SOURCE_CANNOT_HAVE_COPIES": "Les enregistrements de ${0} ne peuvent pas avoir de copies."
}

==> Evergreen-ILS-3.16.2.tar.gz: Evergreen-ILS-3.16.2/Open-ILS/web/js/dojo/openils/opac/nls/fr-ca/opac.js <==
{
    ":BARCODE_PROMPT": "Code-barres : ",
    ":USERNAME_PROMPT": "Nom d'utilisateur : ",
    ":CANCEL_BUTTON_LABEL": "Annuler",
    ":SUBMIT_BUTTON_LABEL": "Soumettre",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "R\u00e9ponse de r\u00e9initialisation du mot de passe",
    ":PWD_RESET_SUBMIT_SUCCESS": "Votre demande de r\u00e9initialisation du mot de passe a \u00e9t\u00e9 trait\u00e9e. Si une adresse de courriel valide est associ\u00e9e \u00e0 votre compte, vous devriez recevoir sous peu un message contenant les instructions permettant la r\u00e9initialisation de votre mot de passe.",
    ":PWD_RESET_SUBMIT_ERROR": "Le syst\u00e8me n'a pas pu traiter votre demande de r\u00e9initialisation du mot de passe. S'il vous pla\u00eet essayez de nouveau, ou contactez le personnel d'aide pratique.",
    ":PWD_RESET_SUBMIT_STATUS": "Envoi de la demande...",
    ":PWD_RESET_FORGOT_PROMPT": "Mot de passe oubli\u00e9 ?",
    ":PWD_RESET_FORM_TITLE": "Demander un nouveau mot de passe",
    ":PWD_RESET_SUBMIT_PROMPT": "Pour d\u00e9buter le processus de renouvellement du mot de passe, indiquez votre code-barres ou votre nom d'utilisateur dans le formulaire ci-dessous et cliquez sur \u00ab Soumettre \u00bb.",
    ":CREATE_MFHD": "enregistrement MFHD ajout\u00e9 pour ${0}",
    ":CREATED_MFHD_RECORD": "enregistrement MFHD cr\u00e9\u00e9 pour ${0}",
    ":DELETE_MFHD": "Supprimer la notice",
    ":DELETE_MFHD_CONFIRM": "\u00cates-vous s\u00fbr de vouloir supprimer cet enregistrement de s\u00e9rie?",
    ":DELETED_MFHD_RECORD": "Supprimer l'enregistrement MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Modifier la notice",
    ":EDIT_MFHD_MENU": "Modifier fonds",
    ":EDIT_PROPERTIES": "Editer les propri\u00e9t\u00e9s",
    ":BASIC_HOLDINGS": "Volumes",
    ":BASIC_HOLDINGS_ADD": "Informations suppl\u00e9mentaires sur le volume",
    ":INDEX_HOLDINGS": "Index",
    ":INDEX_HOLDINGS_ADD": "Informations suppl\u00e9mentaires sur l'index",
    ":CURRENT_HOLDINGS": "Volume actuel",
    ":CURRENT_INDEXES": "index courant",
    ":CURRENT_SUPPLEMENTS": "Suppl\u00e9ments actuels",
    ":HOLDINGS_TABLE_CAPTION": "Sommaire de fonds (${0})",
    ":INCOMPLETE_VOLUMES": "Volumes incomplets",
    ":MISSING_VOLUMES": "Volumes manquants",
    ":ONLINE_VOLUMES": "Volumes en ligne",
    ":SAVE_MFHD_LABEL": "Sauvegarder l'enregistrement MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suppl\u00e9ments",
    ":SUPPLEMENT_HOLDINGS_ADD": "Information suppl\u00e9mentaire",
    ":PLACE_HOLD": "R\u00e9serv\u00e9",
    ":HOLD_STATUS_PLURAL": "hold # ${0} of ${1} total holds and ${2} potential items",
    ":HOLD_STATUS_SINGULAR": "hold # ${0} of ${1} total holds and ${2} potential item",
    ":MORE": "Plus",
    ":MORE_COPIES_FULL_RECORD": "...plus de copies \u00e9num\u00e9r\u00e9s dans l'enregistrement complet",
    ":SOURCE_CANNOT_HAVE_COPIES": "Les enregistrements de ${0} ne peuvent pas avoir de copies."
}
